@@ -22,7 +22,7 @@ const int Bitmap::MaskColor = MASK_COLOR_16;
 const int Bitmap::MODE_TRANS = 0;
 const int Bitmap::MODE_SOLID = 1;
 
-Bitmap * Bitmap::Screen;
+Bitmap * Bitmap::Screen = NULL;
 
 Bitmap::Bitmap():
 error( false ){
@@ -404,6 +404,12 @@ void Bitmap::acquire(){
 	acquire_bitmap( getBitmap() );
 }
 
+void Bitmap::drawBorder( const int border, const int color ) const {
+	for ( int i = 0; i < border; i++ ){
+		rectangle( i, i, getWidth() - i - 1, getHeight() - i - 1, color );
+	}
+}
+
 void Bitmap::release(){
 	release_bitmap( getBitmap() );
 }
@@ -470,17 +476,32 @@ void Bitmap::readLine( vector< int > & vec, int y ){
 	}
 }
 
+static int setGfxMode( int mode, int x, int y ){
+	int ret = ::set_gfx_mode( mode, x, y, 0, 0 );
+	if ( Bitmap::Screen != NULL ){
+		delete Bitmap::Screen;
+	}
+	Bitmap::Screen = new Bitmap( ::screen );
+	return ret;
+}
+
 int Bitmap::setGfxModeText(){
-	return ::set_gfx_mode( GFX_TEXT, 0, 0, 0, 0 );
+	return setGfxMode( GFX_TEXT, 0, 0 );
 }
 	
 int Bitmap::setGfxModeFullscreen( int x, int y ){
-	return ::set_gfx_mode( GFX_AUTODETECT_FULLSCREEN, x, y, 0, 0 );
+	return setGfxMode( GFX_AUTODETECT_FULLSCREEN, x, y );
 }
 
 int Bitmap::setGfxModeWindowed( int x, int y ){
-	return ::set_gfx_mode( GFX_AUTODETECT_WINDOWED, x, y, 0, 0 );
+	return setGfxMode( GFX_AUTODETECT_WINDOWED, x, y );
 }
+
+/*
+int Bitmap::setGfxModeAny( int x, int y ){
+	return setGfxMode( GFX_AUTODETECT, x, y );
+}
+*/
 	
 int Bitmap::makeColor( int r, int g, int b ){
 	return ::makecol16( r, g, b );
