@@ -1,8 +1,8 @@
 #include "defs.h"
 #include "explode.h"
 #include "explode_animate.h"
-#include "allegro.h"
-#include "rafkill.h"
+#include "raptor.h"
+#include "bitmap.h"
 
 ExplosionAnimate::ExplosionAnimate( int cx, int cy, double dx, double dy, int _first_pic, int _last_pic ):
 ExplosionClass( cx, cy, dx, dy, 99 ) {
@@ -23,8 +23,12 @@ bool ExplosionAnimate::update() {
 }
 
 
-void ExplosionAnimate::Draw( BITMAP * who, int offset ) {
-	int mx = ((BITMAP *)global_data[ radius ].dat)->w/2;
-	int my = ((BITMAP *)global_data[ radius ].dat)->h/2;
-	draw_sprite( who, (BITMAP *)global_data[ radius ].dat, x-mx, y-my+offset );
+void ExplosionAnimate::Draw( Bitmap * who, int offset ) {
+	Bitmap frame = Util::getDataSprite( radius );
+	int mx = frame.getWidth() / 2;
+	int my = frame.getHeight() / 2;
+	// draw_sprite( who, (BITMAP *)global_data[ radius ].dat, x-mx, y-my+offset );
+	// Bitmap c( (BITMAP *)Util::global_data[ radius ].dat );
+	// who->draw( 
+	frame.draw( x-mx, y-my+offset, *who );
 }
