@@ -6,61 +6,37 @@
 #include <string.h>
 #include "defs.h"
 #include "strings.h"
-#include "rafkill.h"
+#include "raptor.h"
 #include "ebox.h"
 #include "trigger.h"
 #include "trigtable.h"
-#include "allegro.h"
 #include "group.h"
+#include "bitmap.h"
 #include "playerobj.h"
 #include <vector>
 
 #include "move.h"
 #include "move_find.h"
 
-#include "gun_destruct.h"
-#include "gun_edfstraight.h"
-#include "gun_ednstraight.h"
-#include "gun_eflarge.h"
-#include "gun_efmsingle.h"
-#include "gun_efsingle.h"
-#include "gun_elarge.h"
-#include "gun_emissle.h"
-#include "gun_ecork.h"
-#include "gun_emlight.h"
-#include "gun_eside.h"
-#include "gun_etwirl.h"
-#include "gun_etwirl_find.h"
-#include "gun_etwirl_machine.h"
-#include "gun_estraight.h"
-#include "gun_fire.h"
-
-//#include "hull_ship1.h"
-//#include "hull_ship2.h"
-
-//#include "hull_ship3.h" //heli hull
-#include "hull_ship_heli.h"
-
-//#include "hull_ship4.h"
-
-//#include "hull_ship5.h"
-#include "hull_ship_shield.h"
-
-//#include "hull_ship6.h"
-//#include "hull_ship7.h"
-//#include "hull_ship_destruct.h"
-
-//#include "hull_split.h"
-
-//#include "hull_strong.h"
-
-#include "hull_meteor.h"
-
-//#include "hull_cloud.h"
-//#include "hull_powerup.h"
-//#include "hull_money.h"
-
-#include "hull_animation.h"
+#include "guns/gun_destruct.h"
+#include "guns/gun_edfstraight.h"
+#include "guns/gun_ednstraight.h"
+#include "guns/gun_eflarge.h"
+#include "guns/gun_efmsingle.h"
+#include "guns/gun_efsingle.h"
+#include "guns/gun_elarge.h"
+#include "guns/gun_emissle.h"
+#include "guns/gun_ecork.h"
+#include "guns/gun_emlight.h"
+#include "guns/gun_eside.h"
+#include "guns/gun_etwirl.h"
+#include "guns/gun_etwirl_find.h"
+#include "guns/gun_etwirl_machine.h"
+#include "guns/gun_estraight.h"
+#include "guns/gun_fire.h"
+#include "hulls/hull_ship_shield.h"
+#include "hulls/hull_meteor.h"
+#include "hulls/hull_animation.h"
 
 using namespace std;
 
@@ -78,6 +54,13 @@ using namespace std;
 //2 doubles = dx, dy
 //7 spaces between numbers
 
+static int gl_map( int who );
+
+/* this is ok as long as only one LevelCreator is alive at any one time */
+static vector< Bitmap > hull_money_shadows;
+static ECollide ** gl_collide;
+const int MAX_GL_COLLIDE = (SHIP_LAST-SHIP0_FIRST-1) + 6;
+
 void LevelCreator::makeInfo( char * tmp, int & current ) {
 
 	/*
@@ -172,19 +155,19 @@ Group * LevelCreator::randomGroup( int x, int y ) {
 
 	Group * who_group = new Group( y );
 
-	int gun = rnd( MAX_ENEMY_GUNS );
-	int move = rnd( MAX_ENEMY_MOVE );
-	int hull = rnd( MAX_ENEMY_HULL );
+	int gun = Util::rnd( MAX_ENEMY_GUNS );
+	int move = Util::rnd( MAX_ENEMY_MOVE );
+	int hull = Util::rnd( MAX_ENEMY_HULL );
 	while ( !accept_guns[ gun ] )
-		gun = rnd( MAX_ENEMY_GUNS );
+		gun = Util::rnd( MAX_ENEMY_GUNS );
 	while ( !accept_hull[ hull ] )
-		hull = rnd( MAX_ENEMY_HULL );
+		hull = Util::rnd( MAX_ENEMY_HULL );
 	while ( !accept_move[ move ] )
-		move = rnd( MAX_ENEMY_MOVE );
+		move = Util::rnd( MAX_ENEMY_MOVE );
 
-	double dx = (double)rnd(2000) / 200.0 - 5.0;
-	double dy = (double)rnd(1300) / 300.0 + 3.0;
-	int pattern = rnd( 9 );
+	double dx = (double)Util::rnd(2000) / 200.0 - 5.0;
+	double dy = (double)Util::rnd(1300) / 300.0 + 3.0;
+	int pattern = Util::rnd( 9 );
 
 	switch( pattern ) {
 
@@ -226,7 +209,7 @@ Group * LevelCreator::randomGroup( int x, int y ) {
 		}
 
 		case 4  : {
-			int spacer = rnd( 2 ) * 15 + 20;
+			int spacer = Util::rnd( 2 ) * 15 + 20;
 
 			new EnemyGeneric(x,y,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
 			new EnemyGeneric(x,y-spacer,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
@@ -237,7 +220,7 @@ Group * LevelCreator::randomGroup( int x, int y ) {
 		}
 
 		case 5  : {
-			int spacer = rnd( 5 ) * 10 + 25;
+			int spacer = Util::rnd( 5 ) * 10 + 25;
 			new EnemyGeneric(x,y,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
 			new EnemyGeneric(x,y-spacer*1,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
 			new EnemyGeneric(x,y-spacer*2,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
@@ -251,7 +234,7 @@ Group * LevelCreator::randomGroup( int x, int y ) {
 
 			int ang = 270-20*2;
 			for ( int q = 0; q < 5; q++ ) {
-				new EnemyGeneric((int)(x+tcos[ang]*85),(int)(y+tsine[ang]*90),getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
+				new EnemyGeneric((int)(x+Tcos(ang)*85),(int)(y+Tsine(ang)*90),getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group );
 				ang += 20;
 			}
 
@@ -286,19 +269,19 @@ Group * LevelCreator::randomGroup( int x, int y ) {
 
 void LevelCreator::randomShip( int x, int y, Group * who_group, vector< SpaceObject * > * sh ) {
 
-	int gun = rnd( MAX_ENEMY_GUNS );
-	int move = rnd( MAX_ENEMY_MOVE );
-	int hull = rnd( MAX_ENEMY_HULL );
+	int gun = Util::rnd( MAX_ENEMY_GUNS );
+	int move = Util::rnd( MAX_ENEMY_MOVE );
+	int hull = Util::rnd( MAX_ENEMY_HULL );
 	while ( !accept_guns[ gun ] )
-		gun = rnd( MAX_ENEMY_GUNS );
+		gun = Util::rnd( MAX_ENEMY_GUNS );
 	while ( !accept_hull[ hull ] )
-		hull = rnd( MAX_ENEMY_HULL );
+		hull = Util::rnd( MAX_ENEMY_HULL );
 	while ( !accept_move[ move ] )
-		move = rnd( MAX_ENEMY_MOVE );
+		move = Util::rnd( MAX_ENEMY_MOVE );
 
-	double dx = (double)rnd(2000) / 200.0 - 5.0;
-	double dy = (double)rnd(1300) / 300.0 + 3.0;
-	int pattern = rnd( 9 );
+	double dx = (double)Util::rnd(2000) / 200.0 - 5.0;
+	double dy = (double)Util::rnd(1300) / 300.0 + 3.0;
+	int pattern = Util::rnd( 9 );
 
 	switch( pattern ) {
 
@@ -340,7 +323,7 @@ void LevelCreator::randomShip( int x, int y, Group * who_group, vector< SpaceObj
 		}
 
 		case 4  : {
-			int spacer = rnd( 2 ) * 15 + 20;
+			int spacer = Util::rnd( 2 ) * 15 + 20;
 
 			sh->push_back( new EnemyGeneric(x,y,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
 			sh->push_back( new EnemyGeneric(x,y-spacer,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
@@ -351,7 +334,7 @@ void LevelCreator::randomShip( int x, int y, Group * who_group, vector< SpaceObj
 		}
 
 		case 5  : {
-			int spacer = rnd( 5 ) * 10 + 25;
+			int spacer = Util::rnd( 5 ) * 10 + 25;
 			sh->push_back( new EnemyGeneric(x,y,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
 			sh->push_back( new EnemyGeneric(x,y-spacer*1,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
 			sh->push_back( new EnemyGeneric(x,y-spacer*2,getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
@@ -365,7 +348,7 @@ void LevelCreator::randomShip( int x, int y, Group * who_group, vector< SpaceObj
 
 			int ang = 270-20*2;
 			for ( int q = 0; q < 5; q++ ) {
-				sh->push_back( new EnemyGeneric((int)(x+tcos[ang]*85),(int)(y+tsine[ang]*90),getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
+				sh->push_back( new EnemyGeneric((int)(x+Tcos(ang)*85),(int)(y+Tsine(ang)*90),getHull(hull,1,accept_hull[hull]),getWeapon(gun),getMove(move,dx,dy), who_group ) );
 				ang += 20;
 			}
 
@@ -422,7 +405,7 @@ char * LevelCreator::get_token( char * list, char find ) {
  * - What kind of guns can they have
  * - What kind of movement patterns can they have
  */
-int LevelCreator::processFile( char * file_name ) {
+int LevelCreator::processFile( const char * file_name ) {
 
 	// This function is so obvuios, it needs no comments
 
@@ -544,7 +527,10 @@ double LevelCreator::life_level( double level, int min ) {
 Group * LevelCreator::Boss( int y, int _life ){
 
 	Group * who_group = new Group( y );
-	new EnemyGeneric( screen_x/2 ,y, new HullObject( (BITMAP *)global_data[BOSS_01].dat, _life, SHIP_DAMAGE,1,1,10,false,gl_collide[gl_map(BOSS_01)] ), getWeapon(13),getMove(9,5,5), who_group );
+	/* TODO: fix
+
+	new EnemyGeneric( Util::screen_x/2 ,y, new HullObject( (BITMAP *)global_data[BOSS_01].dat, _life, SHIP_DAMAGE,1,1,10,false,gl_collide[gl_map(BOSS_01)] ), getWeapon(13),getMove(9,5,5), who_group );
+	*/
 
 	return who_group;
 	
@@ -553,21 +539,23 @@ Group * LevelCreator::Boss( int y, int _life ){
 Group * LevelCreator::makeCloud( int x, int y ){
 
 	Group * who_group = new Group( y );
-	double dy = (double)rnd(120) / 50.0 - 1.0;
-	new ShipObject( x, y, 0, new HullObject((BITMAP *)global_data[CLOUD1].dat, 1,0,0,0,rnd( 7 ) + 6, true, NULL ), who_group, new Move( 0, 3.0+dy ), TEAM_ENEMY );
+	// double dy = (double)Util::rnd(120) / 50.0 - 1.0;
+	/* TODO: fix 
+	new ShipObject( x, y, 0, new HullObject((BITMAP *)global_data[CLOUD1].dat, 1,0,0,0,Util::rnd( 7 ) + 6, true, NULL ), who_group, new Move( 0, 3.0+dy ), TEAM_ENEMY );
+	*/
 	return who_group;
 
 
 }
 
-void LevelCreator::load_file( char * file_name, SpaceObject * player ) {
+void LevelCreator::load_file( const char * file_name, SpaceObject * player ) {
 
 	accept_guns = new int[ MAX_ENEMY_GUNS ];
 	accept_hull = new int[ MAX_ENEMY_HULL ];
 	accept_move = new int[ MAX_ENEMY_MOVE ];
 
-	int dif = ( (PlayerObject *)player )->difficulty;
-	double lev = ( (PlayerObject *)player )->level;
+	int dif = ( (PlayerObject *)player )->getDifficulty();
+	double lev = ( (PlayerObject *)player )->getLevel();
 	int min = 1;
 	int max = 2;
 
@@ -592,23 +580,26 @@ void LevelCreator::load_file( char * file_name, SpaceObject * player ) {
 
 	for ( int q = 0; q < MAX_ENEMY_HULL; q++ ) {
 		int ml;
-		ml = rnd( max_life - min_life ) + min_life;
+		ml = Util::rnd( max_life - min_life ) + min_life;
 		accept_hull[q] = ml;
 	}
 
 	if ( processFile( file_name ) != 0 )
 		printf("Error processing %s. Skipping..\n", file_name );
 
+	/* length of level */
 	int peak = 7000 + dif * 250;
 
+	// peak = 500;
+
 	/*
 	for ( int ay = 70; ay < peak; ay += 160 ){
 
-		int m = rnd( dif ) + 1;
+		int m = Util::rnd( dif ) + 1;
 		for ( int ac = 0; ac < m; ac++ ){
 
-			int x = rnd( screen_x - 100 ) + 100;
-			int y = -(ay + rnd( 20 ) - 10 );
+			int x = Util::rnd( Util::screen_x - 100 ) + 100;
+			int y = -(ay + Util::rnd( 20 ) - 10 );
 
 			char * fake_data = new char[ 2 ];
 			trigger * add_t = new trigger( fake_data, 2, SHIP_TRIGGER, x, y );
@@ -620,17 +611,18 @@ void LevelCreator::load_file( char * file_name, SpaceObject * player ) {
 
 	// Make a bunch of groups randomly
 	for ( int ay = 100; ay < peak; ay += 160 ) {
-		int m = rnd( dif ) + 1;
+		int m = Util::rnd( dif ) + 1;
 		for ( int ac = 0; ac < m; ac++ ) {
-			int x = rnd( screen_x - 100 ) + 100;
-			int y = -(ay + rnd( 20 ) - 10 );
+			int x = Util::rnd( Util::screen_x - 100 ) + 100;
+			int y = -(ay + Util::rnd( 20 ) - 10 );
 			group_list.push_back( randomGroup( x, y ) );
 
-			//if ( rnd( 3 ) == rnd( 3 ) )
-			//	group_list.push_back( makeCloud( x, y + rnd( 30 ) ) );
+			//if ( Util::rnd( 3 ) == Util::rnd( 3 ) )
+			//	group_list.push_back( makeCloud( x, y + Util::rnd( 30 ) ) );
 		}
-		if ( rnd( 3 ) )
-			group_list.push_back( makeCloud( rnd( screen_x - 100 ) + 100, -(ay + rnd(30)-10) ) );
+
+		if ( Util::rnd( 3 ) )
+			group_list.push_back( makeCloud( Util::rnd( Util::screen_x - 100 ) + 100, -(ay + Util::rnd(30)-10) ) );
 	}
 
 	// Sup boss..
@@ -638,24 +630,24 @@ void LevelCreator::load_file( char * file_name, SpaceObject * player ) {
 
 	// Make some triggers of varied type
 	char * fake_data = new char[ 2 ];
-	trigger * add_t = new trigger( fake_data, 2, POWER_TRIGGER, rnd( screen_x - 100 ) + 100, -7000 + rnd( 100 ) );
+	trigger * add_t = new trigger( fake_data, 2, POWER_TRIGGER, Util::rnd( Util::screen_x - 100 ) + 100, -7000 + Util::rnd( 100 ) );
 	trigger_list.push_back( add_t );
-	for ( int q = 0; q < rnd( 5 ); q++ ) {
+	for ( int q = 0; q < Util::rnd( 5 ); q++ ) {
 
 		fake_data = new char[ 2 ];
-		*fake_data = rnd( 50 ) + 5;
-		add_t = new trigger( fake_data, 2, METEOR_ON_TRIGGER, rnd( screen_x - 100 ) + 100, -( rnd( 6000 ) + 1000 ) );
+		*fake_data = Util::rnd( 50 ) + 5;
+		add_t = new trigger( fake_data, 2, METEOR_ON_TRIGGER, Util::rnd( Util::screen_x - 100 ) + 100, -( Util::rnd( 6000 ) + 1000 ) );
 		trigger_list.push_back( add_t );
 
 	}
-	for ( int q = 0; q < rnd( 5 ); q++ ) {
+	for ( int q = 0; q < Util::rnd( 5 ); q++ ) {
 		fake_data = new char[ 2 ];
-		add_t = new trigger( fake_data, 2, METEOR_OFF_TRIGGER, rnd( screen_x - 100 ) + 100, -( rnd( 6000 ) + 1000 ) );
+		add_t = new trigger( fake_data, 2, METEOR_OFF_TRIGGER, Util::rnd( Util::screen_x - 100 ) + 100, -( Util::rnd( 6000 ) + 1000 ) );
 		trigger_list.push_back( add_t );
 	}
-	for ( int q = 0; q < rnd( 3 ); q++ ) {
+	for ( int q = 0; q < Util::rnd( 3 ); q++ ) {
 		fake_data = new char[ 2 ];
-		add_t = new trigger( fake_data, 2, HEALTH_TRIGGER, rnd( screen_x - 100 ) + 100, -( rnd( 4000 ) + 3000 ) );
+		add_t = new trigger( fake_data, 2, HEALTH_TRIGGER, Util::rnd( Util::screen_x - 100 ) + 100, -( Util::rnd( 4000 ) + 3000 ) );
 		trigger_list.push_back( add_t );
 	}
 }
@@ -663,7 +655,7 @@ void LevelCreator::load_file( char * file_name, SpaceObject * player ) {
 /* LevelCreator:
  * Constructor. Creates all ECollides that enemies will use. Loads the level from a file.
  */
-LevelCreator::LevelCreator( char * file_name, SpaceObject * player ) {
+LevelCreator::LevelCreator( const char * file_name, SpaceObject * player ) {
 	//info = new info_holder*[ MAX_SHIPS ];
 	counter = 0;
 	lerror = false;
@@ -674,40 +666,54 @@ LevelCreator::LevelCreator( char * file_name, SpaceObject * player ) {
 
 	trigger_list.clear();
 
-	#define MAX_GL_COLLIDE ((SHIP_LAST-SHIP0_FIRST-1)+6)
 
 	//total collide objects = total ships + meteor + money + powerup + weaponup + health + boss
 	gl_collide = new ECollide*[ MAX_GL_COLLIDE ];
 	for ( int q = 0; q < MAX_GL_COLLIDE; q++ )
 		gl_collide[q] = NULL;
-	for ( int q = SHIP0_FIRST+1; q < SHIP_LAST; q++ )
-		gl_collide[ gl_map( q ) ] = new ECollide((BITMAP *)global_data[q].dat,6,makecol(255,0,255),42);
-	gl_collide[ gl_map(METEOR_1) ] = new ECollide((BITMAP *)global_data[METEOR_1].dat,6,makecol(255,0,255),45);
-	gl_collide[ gl_map(COIN_1) ] = new ECollide((BITMAP *)global_data[COIN_1].dat,6,makecol(255,0,255),52);
-	gl_collide[ gl_map(POWERUP_1)] = new ECollide((BITMAP *)global_data[POWERUP_1].dat,6,makecol(255,0,255),52);
-	gl_collide[ gl_map(WEAPONUP_001) ] = new ECollide((BITMAP *)global_data[WEAPONUP_001].dat,6,makecol(255,0,255),52);
-	gl_collide[ gl_map(HEALTH_001) ] = new ECollide( (BITMAP *)global_data[HEALTH_001].dat,6,makecol(255,0,255),52);
-	gl_collide[ gl_map(BOSS_01) ] = new ECollide( (BITMAP *)global_data[BOSS_01].dat,6,makecol(255,0,255),52);
+	for ( int q = SHIP0_FIRST+1; q < SHIP_LAST; q++ ){
+		// gl_collide[ gl_map( q ) ] = new ECollide((BITMAP *)global_data[q].dat,6,makecol(255,0,255),42);
+		Bitmap l = Util::getDataSprite( q );
+		gl_collide[ gl_map( q ) ] = new ECollide( &l );
+	}
 
-	char * final_file = data_file( file_name );
+	// gl_collide[ gl_map(METEOR_1) ] = new ECollide((BITMAP *)global_data[METEOR_1].dat);
+	gl_collide[ gl_map(METEOR_1) ] = new ECollide( Util::getDataSprite( METEOR_1 ) );
+	gl_collide[ gl_map(COIN_1) ] = new ECollide( Util::getDataSprite( COIN_1 ) );
+	gl_collide[ gl_map(POWERUP_1)] = new ECollide( Util::getDataSprite( POWERUP_1 ) );
+	gl_collide[ gl_map(WEAPONUP_001) ] = new ECollide( Util::getDataSprite( WEAPONUP_001 ) );
+	gl_collide[ gl_map(HEALTH_001) ] = new ECollide( Util::getDataSprite( HEALTH_001 ) );
+	gl_collide[ gl_map(BOSS_01) ] = new ECollide( Util::getDataSprite( BOSS_01 ) );
+	/*
+	gl_collide[ gl_map(METEOR_1) ] = new ECollide((BITMAP *)Util::global_data[METEOR_1].dat,6,makecol(255,0,255),45);
+	gl_collide[ gl_map(COIN_1) ] = new ECollide((BITMAP *)Util::global_data[COIN_1].dat,6,makecol(255,0,255),52);
+	gl_collide[ gl_map(POWERUP_1)] = new ECollide((BITMAP *)Util::global_data[POWERUP_1].dat,6,makecol(255,0,255),52);
+	gl_collide[ gl_map(WEAPONUP_001) ] = new ECollide((BITMAP *)Util::global_data[WEAPONUP_001].dat,6,makecol(255,0,255),52);
+	gl_collide[ gl_map(HEALTH_001) ] = new ECollide( (BITMAP *)Util::global_data[HEALTH_001].dat,6,makecol(255,0,255),52);
+	gl_collide[ gl_map(BOSS_01) ] = new ECollide( (BITMAP *)Util::global_data[BOSS_01].dat,6,makecol(255,0,255),52);
+	*/
+
+	char final_file[ 4096 ];
+	Util::getDataPath( final_file, file_name );
+	// char * final_file = Util::data_file( file_name );
 
 	group_list.clear();
 	load_file( final_file, player );
-	free( final_file );
+	// free( final_file );
 
 	current_counter = 0;
 
 	int mpics = COIN_A_20 - COIN_1 + 1;
-	max_money_shadow = mpics;
-	hull_money_shadows = new BITMAP*[ mpics ];
 	for ( int q = 0; q < mpics; q++ ){
-		BITMAP * use = (BITMAP *)global_data[COIN_1+q].dat;
-		hull_money_shadows[q] = create_bitmap( use->w, use->h );
-		int m = 22;
-		clear_to_color( hull_money_shadows[q], makecol(m,m,m) );
-		draw_mask( hull_money_shadows[q], use, 0, 0 );
-	}
 
+		Bitmap bitmap = Bitmap( Util::getDataSprite( COIN_1 + q ), true );
+		Bitmap use = Util::getDataSprite( COIN_1 + q );
+
+		hull_money_shadows.push_back( bitmap );
+		int m = 22;
+		bitmap.fill( Bitmap::makeColor( m, m, m ) );
+		use.drawMask( 0, 0, bitmap );
+	}
 }
 
 /* noExist:
@@ -726,7 +732,7 @@ void LevelCreator::Draw( BITMAP * work, int xfac, int yfac ) {
 /* gl_map:
  * Recursive call to find the appropriate value for a defined constant
  */
-int LevelCreator::gl_map( int who ) {
+static int gl_map( int who ) {
 
 	if ( who >= SHIP0_FIRST && who <= SHIP_LAST )
 		return who-(SHIP0_FIRST+1);
@@ -770,21 +776,78 @@ bool LevelCreator::done() {
 /*
 void LevelCreator::emergency( vector< SpaceObject * > * sh ){
 
-	if ( rnd( 260 ) == rnd( 260 ) ){
+	if ( Util::rnd( 260 ) == Util::rnd( 260 ) ){
 
-		int x = rnd( screen_x - 50 ) + 50;
+		int x = Util::rnd( Util::screen_x - 50 ) + 50;
 		int y = -100;
 
 		int mpics = HEALTH_021 - HEALTH_001 + 1;
 		BITMAP ** pics = new BITMAP*[ mpics ];
 		for ( int q = 0; q < mpics; q++ )
-pics[ q ] = (BITMAP *)global_data[ HEALTH_001 + q ].dat;
+pics[ q ] = (BITMAP *)Util::global_data[ HEALTH_001 + q ].dat;
 
 sh->push_back(new Health(x,y,new HullAnimation( pics, mpics,1,0,0,0,10,false,gl_collide[gl_map(HEALTH_001)]),new Move(0,4.5)));
 }
 }
 */
 
+static SpaceObject * createCloak( const int x, const int y ){
+	vector< Bitmap > pics;
+	int mpics = 0;
+
+	mpics = WEAPONUP_020 - WEAPONUP_001 + 1;
+	for ( int q = 0; q < mpics; q++ ){
+		pics.push_back( Util::getDataSprite( WEAPONUP_001 + q ) );
+	}
+	return new Cloak( x, y, new HullAnimation(pics, vector< Bitmap >(), 1, 0, 0, 0, 10, false, gl_collide[gl_map(WEAPONUP_001)]), new Move(0,2.5) );
+
+}
+
+static SpaceObject * createPowerUp( const int x, const int y ){
+	vector< Bitmap > pics;
+
+	int mpics = POWERUP_A_14 - POWERUP_1 + 1;
+	for ( int q = 0; q < mpics; q++ ){
+		pics.push_back( Util::getDataSprite( POWERUP_1 + q ) );
+	}
+	return new PowerUp( x, y, new HullAnimation( pics, vector< Bitmap >(), 1, 0, 0, 0, 10, false, gl_collide[gl_map(POWERUP_1)]), new Move(0,2.5) );
+
+}
+
+static SpaceObject * createHealth( const int x, const int y ){
+
+	vector< Bitmap > pics;
+	int mpics = HEALTH_021 - HEALTH_001 + 1;
+	for ( int q = 0; q < mpics; q++ ){
+		pics.push_back( Util::getDataSprite( HEALTH_001 + q ) );
+	}
+	return new Health( x, y, new HullAnimation(pics,vector< Bitmap >(), 1, 0, 0, 0, 10, false, gl_collide[gl_map(HEALTH_001)]), new Move( 0, 2.5 ) );
+
+}
+
+static SpaceObject * createMoney( const int x, const int y, const SpaceObject * player ){
+
+	vector< Bitmap > pics;
+	int mpics = COIN_A_20 - COIN_1 + 1;
+	for ( int q = 0; q < mpics; q++ ){
+		pics.push_back( Util::getDataSprite( COIN_1 + q ) );
+	}
+
+	int lev = -1;
+	int min = 10;
+	int max = 4000;
+	if ( player != NULL ) {
+		lev = ( (PlayerObject *)player )->getLevel();
+		min = 10*lev;
+		max = 2000*lev;
+	}
+
+	int q = Util::rnd( max - min ) + min;
+
+	return new Money( x, y, q, new HullAnimation( pics, hull_money_shadows, 1, 0, 0, 0, 10, false, gl_collide[gl_map(COIN_1)] ), new Move( 0, 2 ) );
+
+}
+
 /* special:
  * Makes a special item. Can be one of the following:
  * - Powerup
@@ -792,63 +855,29 @@ sh->push_back(new Health(x,y,new HullAnimation( pics, mpics,1,0,0,0,10,false,gl_
  * - Health
  * - Money
  */
-SpaceObject * LevelCreator::special( int x, int y, SpaceObject * player ) {
+SpaceObject * LevelCreator::special( int x, int y, const SpaceObject * player ) {
 
-	BITMAP ** pics;
-	int mpics = 0;
 
-	if ( rnd( 50 ) == rnd( 50 ) ) {
-		mpics = WEAPONUP_020 - WEAPONUP_001 + 1;
-		pics = new BITMAP * [ mpics ];
-		for ( int q = 0; q < mpics; q++ )
-			pics[q] = (BITMAP *)global_data[ WEAPONUP_001 + q ].dat;
-		return new Cloak( x, y, new HullAnimation(pics,mpics,NULL,1,0,0,0,10,false,gl_collide[gl_map(WEAPONUP_001)]), new Move(0,2.5) );
+	if ( Util::rnd( 50 ) == Util::rnd( 50 ) ) {
+		return createCloak( x, y );
 	}
 
-	if ( rnd( 60 ) == rnd( 60 ) ) {
-		mpics = POWERUP_A_14 - POWERUP_1 + 1;
-		pics = new BITMAP * [ mpics ];
-		for ( int q = 0; q < mpics; q++ )
-			pics[q] = (BITMAP *)global_data[ POWERUP_1 + q ].dat;
-		return new PowerUp( x, y, new HullAnimation(pics,mpics,NULL,1,0,0,0,10,false,gl_collide[gl_map(POWERUP_1)]), new Move(0,2.5) );
+	if ( Util::rnd( 60 ) == Util::rnd( 60 ) ) {
+		return createPowerUp( x, y );
 	}
 
+	/* if the player has low life increase the chances a health will appear */
 	int h_rnd = 21;
-	if ( player != NULL )
+	if ( player != NULL ){
 		if ( player->getLife() < 30 ) h_rnd = 4;
-
-	if ( rnd( h_rnd ) == rnd( h_rnd ) ) {
-		mpics = HEALTH_021 - HEALTH_001 + 1;
-		pics = new BITMAP * [ mpics ];
-		for ( int q = 0; q < mpics; q++ )
-			pics[q] = (BITMAP *)global_data[ HEALTH_001 + q ].dat;
-		return new Health( x, y, new HullAnimation(pics,mpics,NULL,1,0,0,0,10,false,gl_collide[gl_map(HEALTH_001)]), new Move(0,2.5) );
 	}
 
-	mpics = COIN_A_20 - COIN_1 + 1;
-	pics = new BITMAP*[ mpics ];
-	for ( int q = 0; q < mpics; q++ )
-		pics[q] = (BITMAP *)global_data[ COIN_1+q ].dat;
-
-	int lev = -1;
-	int min = 10;
-	int max = 4000;
-	if ( player != NULL ) {
-		lev = ( (PlayerObject *)player )->level;
-		min = 10*lev;
-		max = 2000*lev;
+	if ( Util::rnd( h_rnd ) == Util::rnd( h_rnd ) ) {
+		return createHealth( x, y );
 	}
 
-	/*
-	int q = rnd( 100 );
-	if ( q > 92 ) q = ( rnd(2) + 1 ) * 2000;
-	else if ( q > 86 ) q = ( rnd(2) + 1 ) * 1200;
-	else if ( q > 71 ) q = ( rnd(3) + 1 ) * 600;
-	else q = (rnd(5) + 1 ) * 25;
-	*/
-	int q = rnd(max-min)+min;
-
-	return new Money( x, y, q, new HullAnimation( pics, mpics, hull_money_shadows,1, 0,0,0,10,false,gl_collide[gl_map(COIN_1)] ), new Move( 0, 2 ) );
+	return createMoney( x, y, player );
+	// return NULL;
 
 }
 
@@ -857,19 +886,21 @@ SpaceObject * LevelCreator::special( int x, int y, SpaceObject * player ) {
  */
 HullObject * LevelCreator::getHull( int a, int l, int _life ) {
 	a++;
+
+	/* TODO: fix
 	switch( a ) {
 		//case 0  :       return new OrbHull( l );
 		//case 1  :       return new ShardHull( l );
-		//case 2  :       return new TangoHull( rnd(32) + 32, l );
-		//case 3  :       return new HeliHull( (BITMAP *)global_data[SHIP_003].dat, _life, l, gl_collide[gl_map(SHIP_003)] );
-		case 5  :       return new ShieldHull( (BITMAP *)global_data[SHIP_005].dat, _life, l, gl_collide[gl_map(SHIP_005)] );
-		//case 5	:	return new StrongHull( rnd(32) + 32, l );
-		//case 6	:	return new SplitHull( rnd(32) + 32, l );
+		//case 2  :       return new TangoHull( Util::rnd(32) + 32, l );
+		//case 3  :       return new HeliHull( (BITMAP *)Util::global_data[SHIP_003].dat, _life, l, gl_collide[gl_map(SHIP_003)] );
+		case 5  :       return new ShieldHull( (BITMAP *)Util::global_data[SHIP_005].dat, _life, l, gl_collide[gl_map(SHIP_005)] );
+		//case 5	:	return new StrongHull( Util::rnd(32) + 32, l );
+		//case 6	:	return new SplitHull( Util::rnd(32) + 32, l );
 		//case 7	:	return new HullObject( BLOCK, 100, 0, 0, 0, 8, NULL );
 		//case 8	:	return new Ship6(l);
 		//case 9	:	return new Ship7(l);
 		case 8 : {
-			HullObject * h = new HullObject( (BITMAP *)global_data[SHIP_008].dat,_life,SHIP_DAMAGE,2,l,10,false,gl_collide[gl_map(SHIP0_FIRST+a)] );
+			HullObject * h = new HullObject( (BITMAP *)Util::global_data[SHIP_008].dat,_life,SHIP_DAMAGE,2,l,10,false,gl_collide[gl_map(SHIP0_FIRST+a)] );
 			h->giveWeapon( new GunDestruct(1,TEAM_ENEMY), 1 );
 			return h;
 		}
@@ -878,13 +909,14 @@ HullObject * LevelCreator::getHull( int a, int l, int _life ) {
 			int mpics = HELICOPTER_6 - HELICOPTER_1 + 1;
 			BITMAP ** pics = new BITMAP*[ mpics ];
 			for ( int q = 0; q < mpics; q++ )
-				pics[q] = (BITMAP *)global_data[ HELICOPTER_1 + q ].dat;
+				pics[q] = (BITMAP *)Util::global_data[ HELICOPTER_1 + q ].dat;
 
 			return new HullAnimation( pics, mpics, NULL,_life, SHIP_DAMAGE, 1, l, 10, false, gl_collide[gl_map(SHIP0_FIRST+a)] );
 
 		}
 	}
-	return new HullObject( (BITMAP * )global_data[SHIP0_FIRST+a].dat, _life, SHIP_DAMAGE,1,l,10,false,gl_collide[gl_map(SHIP0_FIRST+a)] );
+	*/
+	return new HullObject( new Bitmap( Util::getDataSprite( SHIP0_FIRST + a ) ), _life, SHIP_DAMAGE,1,l,10,false,gl_collide[gl_map(SHIP0_FIRST+a)] );
 }
 
 
@@ -954,7 +986,7 @@ SpaceObject * LevelCreator::GetEnemy( int cx, int cy, int hu,int we,int m,double
 	//HullObject * can;
 	/*
 	if ( hullNum( hu, 1 ) == -1 ) can = GetHull(hu,1);
-	else can = new HullObject( hullNum(hu,1), 20+rnd(15), SHIP_DAMAGE, 1, 1, 10,gl_collide[gl_map(hullNum(hu,1))]);
+	else can = new HullObject( hullNum(hu,1), 20+Util::rnd(15), SHIP_DAMAGE, 1, 1, 10,gl_collide[gl_map(hullNum(hu,1))]);
 	*/
 	//can = GetHull( hu, 1 );
 
@@ -965,25 +997,29 @@ SpaceObject * LevelCreator::GetEnemy( int cx, int cy, int hu,int we,int m,double
 /* create:
  * Puts new enemies into the enemy list.
  */
-void LevelCreator::create( vector< SpaceObject * > * sh, int leva, double & speed ) {
+void LevelCreator::create( vector< SpaceObject * > * sh, int leva, const double & speed ) {
 
 	current_counter -= 2;
 
-	// Search through all the groups. If group is close enough to the player, put
-	// all the ships the group contains into the object list passed to create via sh.
+	/* Search through all the groups. If group is close enough to the player, put
+	 * all the ships the group contains into the object list passed to create via `sh'.
+	 */
 	for ( vector< class Group * >::iterator it = group_list.begin(); it != group_list.end(); ) {
 
-		if ( (*it)->pos() + 100 >= current_counter ) {
-			for ( vector< class SpaceObject * >::iterator vv = (*it)->members()->begin(); vv != (*it)->members()->end(); vv++ ) {
-				(*vv)->SetCoordXY( (*vv)->actualx, (*vv)->actualy - (*it)->pos() - 100 );
-				sh->push_back( *vv );
+		Group * group = *it;
+
+		if ( group->pos() + 100 >= current_counter ) {
+			for ( vector< class SpaceObject * >::const_iterator vv = group->members()->begin(); vv != group->members()->end(); vv++ ) {
+				SpaceObject * object = *vv;
+				object->SetCoordXY( object->getX(), object->getY() - group->pos() - 100 );
+				sh->push_back( object );
 			}
 			it = group_list.erase( it );
 		} else ++it;
 
 	}
 
-	// Search through all triggers and activate them if they are close enough to the player
+	/* Search through all triggers and activate them if they are close enough to the player */
 	for ( vector< class trigger * >::iterator it = trigger_list.begin(); it != trigger_list.end(); it++ ) {
 
 		if ( (*it)->CY()+100 >= current_counter ) {
@@ -1000,11 +1036,13 @@ void LevelCreator::create( vector< SpaceObject * > * sh, int leva, double & spee
 				*/
 				// Power_Trigger: Creates a powerup
 				case POWER_TRIGGER      : {
+					/* TODO: fix
 					int mpics = POWERUP_A_14 - POWERUP_1 + 1;
 					BITMAP ** pics = new BITMAP * [ mpics ];
 					for ( int q = 0; q < mpics; q++ )
 						pics[q] = (BITMAP *)global_data[ POWERUP_1 + q ].dat;
 					sh->push_back( new PowerUp( (*it)->CX(), -100, new HullAnimation(pics,mpics,NULL,1,0,0,0,10,false,gl_collide[gl_map(POWERUP_1)]), new Move(0,5) ) );
+					*/
 					break;
 
 				}
@@ -1022,11 +1060,13 @@ void LevelCreator::create( vector< SpaceObject * > * sh, int leva, double & spee
 				// Health_trigger: Creates a health.
 				case HEALTH_TRIGGER     : {
 
+					/* TODO: fix
 					int mpics = HEALTH_021 - HEALTH_001 + 1;
 					BITMAP ** pics = new BITMAP * [ mpics ];
 					for ( int q = 0; q < mpics; q++ )
 						pics[q] = (BITMAP *)global_data[ HEALTH_001 + q ].dat;
 					sh->push_back( new Health( (*it)->CX(), -100, new HullAnimation(pics,mpics,NULL,1,0,0,0,10,false,gl_collide[gl_map(HEALTH_001)]), new Move(0,4.5) ) );
+					*/
 
 					break;
 				}
@@ -1039,43 +1079,47 @@ void LevelCreator::create( vector< SpaceObject * > * sh, int leva, double & spee
 
 	}
 
-	// Delete all triggers that have been killed
-	for ( vector< class trigger * >::iterator it = trigger_list.begin(); it != trigger_list.end(); )
-	if ( (*it)->kind() == -1 ) {
-		trigger * temp = *it;
-		it = trigger_list.erase( it );
-		delete temp;
-	} else ++it;
+	/* Delete all triggers that have been killed */
+	for ( vector< class trigger * >::iterator it = trigger_list.begin(); it != trigger_list.end(); ){
+		if ( (*it)->kind() == -1 ) {
+			trigger * temp = *it;
+			it = trigger_list.erase( it );
+			delete temp;
+		} else ++it;
+	}
 
-	// Game isnt over, so make some whacky things for your amusement!
+	/* Game isnt over, so make some whacky things for your amusement! */
 	if ( !done() ) {
 
 		if ( num_cloud ) num_cloud--;
 
 		// Make a meteor with some velocity
-		if ( rnd( meteor_chance ) == rnd( meteor_chance ) && meteor_chance > 0 ) {
-			double dx = (double)( rnd(90) ) / (double)( 25 ) * (rnd(2)*2-1);
-			double dy = (double)( rnd(200) ) / (double)( 25 ) + 2.3;
+		if ( Util::rnd( meteor_chance ) == Util::rnd( meteor_chance ) && meteor_chance > 0 ) {
+
+			/* TODO: fix
+			double dx = (double)( Util::rnd(90) ) / (double)( 25 ) * (Util::rnd(2)*2-1);
+			double dy = (double)( Util::rnd(200) ) / (double)( 25 ) + 2.3;
 			//int lv = (int)( 25.0 + real_level * 2 );
-			//SpaceObject * use =  new ShipObject( rnd( 640 ), rnd( 30 ) - 50, 40, new MeteorHull(leva,lv,gl_collide[ gl_map(METEOR_1) ] ), NULL, new Move(dx,dy), TEAM_ENEMY );
+			//SpaceObject * use =  new ShipObject( Util::rnd( 640 ), Util::rnd( 30 ) - 50, 40, new MeteorHull(leva,lv,gl_collide[ gl_map(METEOR_1) ] ), NULL, new Move(dx,dy), TEAM_ENEMY );
 			int mpics = METEOR_9_20 - METEOR_1 + 1;
 			BITMAP ** pics = new BITMAP*[ mpics ];
 			for ( int q = 0; q < mpics; q++ )
 				pics[ q ] = (BITMAP *)global_data[ METEOR_1 + q ].dat;
 
-			SpaceObject * use = new MeteorObject(rnd(640),rnd(30)-50,-meteor_life*3, new HullAnimation( pics, mpics,NULL,meteor_life,0,0,0,10,false,gl_collide[gl_map(METEOR_1)]), new Move(dx,dy) );
+			SpaceObject * use = new MeteorObject(Util::rnd(640),Util::rnd(30)-50,-meteor_life*3, new HullAnimation( pics, mpics,NULL,meteor_life,0,0,0,10,false,gl_collide[gl_map(METEOR_1)]), new Move(dx,dy) );
 
 			sh->push_back( use );
+			*/
 		}
 
 		/*
-		else if ( rnd( 80 ) == rnd( 80 ) && !num_cloud ) {
+		else if ( Util::rnd( 80 ) == Util::rnd( 80 ) && !num_cloud ) {
 
 			// Make a fancy cloud!
 			num_cloud = 60;
 
-			double dy = (double)rnd(120) / 50.0 - 1.0;
-			SpaceObject * use = new ShipObject( rnd(640), -200, 0, new HullObject((BITMAP *)global_data[CLOUD1].dat, 1,0,0,0,rnd( 7 ) + 6, true, NULL ), NULL, new Move( 0, 3.0+dy ), TEAM_ENEMY );
+			double dy = (double)Util::rnd(120) / 50.0 - 1.0;
+			SpaceObject * use = new ShipObject( Util::rnd(640), -200, 0, new HullObject((BITMAP *)global_data[CLOUD1].dat, 1,0,0,0,Util::rnd( 7 ) + 6, true, NULL ), NULL, new Move( 0, 3.0+dy ), TEAM_ENEMY );
 			sh->push_back( use );
 		}
 		*/
@@ -1109,8 +1153,12 @@ LevelCreator::~LevelCreator() {
 	delete[] accept_hull;
 	delete[] accept_guns;
 	delete[] accept_move;
+	
+	hull_money_shadows.clear();
 
+	/*
 	for ( int q = 0; q < max_money_shadow; q++ )
 		destroy_bitmap( hull_money_shadows[q] );
 	delete[] hull_money_shadows;
+	*/
 }
