@@ -9,6 +9,7 @@
 #include "keyboard.h"
 #include "strings.h"
 #include <string.h>
+#include <sstream>
 #include <iostream>
 #include "loadsave.h"
 #include "defs.h"
@@ -16,6 +17,7 @@
 #include "raptor.h"
 #include "sound.h"
 #include "rmenu.h"
+#include "rfield.h"
 #include "hull.h"
 #include "wormhole.h"
 #include "explode.h"
@@ -26,6 +28,8 @@
 #include "playerobj.h"
 #include "guns/gun_machine.h"
 
+#include "config.h"
+
 #ifndef debug
 #define debug cout << "File: " << __FILE__ << " Line: " << __LINE__ << endl;
 #endif
@@ -41,23 +45,28 @@ static const int INIT_QUIT = 3;
 static const int INIT_CREDITS = 4;
 static const int INIT_BACK = 6;
 static const int INIT_SAVE = 7;
+static const int INIT_CHANGE_KEYS = 8;
 static const int INIT_LOAD = 5000;
 static const int INC_RATE = 10;
 static const int DEC_RATE = 11;
 static const int INIT_HELP = 12;
-static const int INIT_SCREEN_FULL = 13;
-static const int INIT_SCREEN_WINDOW = 14;
+static const int INIT_SCREEN = 13;
 static const int SOUND_INC = 15;
 static const int SOUND_DEC = 16;
 static const int MUSIC_INC = 17;
 static const int MUSIC_DEC = 18;
 static const int DIFFICULT_MENU = 1000;
 
+static const int CHANGE_KEY_FORWARD = 20;
+static const int CHANGE_KEY_BACKWARD = 21;
+static const int CHANGE_KEY_LEFT = 22;
+static const int CHANGE_KEY_RIGHT = 23;
+static const int CHANGE_KEY_SHOOT = 24;
+
 static Font * normalFont = NULL;
 
 extern void init( int GFX, int GAME_SPEED );
 
-
 void credits() {
 	cout << "Exiting normally.. " << endl;
 	cout << "-------" << endl;
@@ -222,7 +231,7 @@ void getLoadMenu( RMenu * menu, int load_num, int select_smp ){
 		}
 	}
 	
-	menu->addMenu( strdup("Return"), normalFont, true, 800, NULL, select_smp );
+	menu->addMenu( "Return", normalFont, true, 800, NULL, select_smp );
 }
 
 void popUp( const char * title ){
@@ -238,8 +247,8 @@ void popUp( const char * title ){
 	sell_screen.rectangle( begin, 80, begin+length, 235, Bitmap::makeColor(255,255,255) );
 	Bitmap::drawingMode( Bitmap::MODE_SOLID );
 	RMenu sell( sell_screen, begin+10, 100, 1000, Bitmap::makeColor(80,0,0), Bitmap::makeColor(255,136,0), RAPTOR_TITLE_COLOR );
-	sell.addTitle(strdup( title ), normalFont );
-	sell.addMenu( strdup("OK"), normalFont, true, 1, &sell, NO_SOUND );
+	sell.addTitle( title, normalFont );
+	sell.addMenu( "OK", normalFont, true, 1, &sell, NO_SOUND );
 	sell.init();
 
 	int call = -1;
@@ -257,15 +266,39 @@ void popUp( const char * title ){
 	// destroy_bitmap( sell_screen );
 }
 
-int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** player, DATAFILE * sound ){
+static int userSelectKey(){
+
+	Bitmap work( normalFont->textLength( "Press a key" ) + 20, 50 );
+	work.fill( Bitmap::makeColor( 32, 32, 32 ) );
+
+	work.printf( 10, 10, Bitmap::makeColor( 200, 64, 23 ), normalFont, "Press a key" );
+	work.drawBorder( 2, Bitmap::makeColor( 200, 200, 200 ) );
+
+	work.drawTrans( GRAPHICS_X / 2 - work.getWidth() / 2, GRAPHICS_Y / 2 - work.getHeight() / 2 - 100, *Bitmap::Screen );
+
+	while ( Keyboard::readKey() != -1 ){
+		Util::YIELD();
+	}
+
+	int key = Keyboard::readKey();
+	while ( key == -1 ){
+		Util::YIELD();
+		key = Keyboard::readKey();
+	}
+
+	while ( Keyboard::keyPressed() ){
+		Util::YIELD();
+	}
+
+	return key;
+}
+
+int intro_screen( int & frames, SpaceObject ** player, DATAFILE * sound ){
 
-	//RGB * crap = new RGB[256];
-	// char * file_name_pcx = Util::data_file( "logosmoot.pcx" );
 	char backgroundFile[ 4096 ];
 	Util::getDataPath( backgroundFile, "logosmoot.pcx" );
 	Bitmap intr( backgroundFile );
-	// free( file_name_pcx );
-	//delete[] crap;
+
 	if ( intr.getError() ) {
 		string message = "Could not load: ";
 		message += backgroundFile;
@@ -273,64 +306,64 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 		return 3;
 	}
 
-	/*
-	DUH * dumb_file = NULL;
-	AL_DUH_PLAYER * dumb_player = NULL;
-	char * d_file = data_file( "intro.mod" );
-	dumb_file = dumb_load_mod( d_file );
-	free( d_file );
-	dumb_player = al_start_duh( dumb_file, 2, 0, music_vol, 4096, 22050 );
-	*/
-
 	int select_smp = INTRO_MENU_SELECT;
 
-	/*
-	RMenu * intro_menu = new RMenu( intr, 170, 220, makecol(120,0,0),makecol(255,0,0), RAPTOR_TITLE_COLOR);
-	RMenu * option_menu = new RMenu( intr, 1, 120, makecol(120,0,0),makecol(255,0,0), RAPTOR_TITLE_COLOR );
-	RMenu * frame_menu = new RMenu( intr, 1, 230, makecol(120,0,0),makecol(255,0,0), RAPTOR_TITLE_COLOR );
-	RMenu * difficulty_menu = new RMenu( intr, 1, 210, makecol(120,0,0),makecol(255,0,0), RAPTOR_TITLE_COLOR );
-	RMenu * sound_menu = new RMenu( intr, 1, 145, makecol(120,0,0), makecol(255,0,0), RAPTOR_TITLE_COLOR );
-	*/
 	RMenu intro_menu( intr, 170, 200, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR);
 	RMenu option_menu( intr, 1, 120, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR );
 	RMenu frame_menu( intr, 1, 230, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR );
 	RMenu difficulty_menu( intr, 1, 180, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR );
+	RMenu changeKeyMenu( intr, 1, 180, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR );
 	RMenu sound_menu( intr, 1, 145, 1000, Bitmap::makeColor(120,0,0), Bitmap::makeColor(255,0,0), RAPTOR_TITLE_COLOR );
 	RMenu load_menu( intr, 1, 200, 1000, Bitmap::makeColor(128,64,0), Bitmap::makeColor(255,128,0), RAPTOR_TITLE_COLOR );
 
-	// load_menu.addMenu( strdup("Return"), Util::raptor_font, true, 800, NULL, select_smp );
+	// load_menu.addMenu( "Return", Util::raptor_font, true, 800, NULL, select_smp );
 	getLoadMenu( &load_menu, INIT_LOAD, select_smp );
 
 	if ( *player != NULL ){
-		intro_menu.addMenu( strdup("Continue"), normalFont, true, INIT_CONTINUE,NULL,select_smp);
+		intro_menu.addMenu( "Continue", normalFont, true, INIT_CONTINUE,NULL,select_smp);
 	}
 
-	intro_menu.addMenu( strdup("Play new"), normalFont, true,INIT_PLAY,NULL,select_smp);
-	intro_menu.addMenu( strdup("Load Game"), normalFont, true,INIT_LOAD,&load_menu,select_smp);
-	intro_menu.addMenu( strdup("Options"), normalFont, true,INIT_OPT,&option_menu,select_smp);
-	intro_menu.addMenu( strdup("Credits"), normalFont, true,INIT_CREDITS,&intro_menu,select_smp);
-	intro_menu.addMenu( strdup("Quit"), normalFont, true,INIT_QUIT,NULL,select_smp);
+	intro_menu.addMenu( "Play new", normalFont, true,INIT_PLAY,NULL,select_smp);
+	intro_menu.addMenu( "Load Game", normalFont, true,INIT_LOAD,&load_menu,select_smp);
+	intro_menu.addMenu( "Options", normalFont, true,INIT_OPT,&option_menu,select_smp);
+	intro_menu.addMenu( "Credits", normalFont, true,INIT_CREDITS,&intro_menu,select_smp);
+	intro_menu.addMenu( "Quit", normalFont, true,INIT_QUIT,NULL,select_smp);
 
-	option_menu.addTitle( strdup("Options"), normalFont );
-	char * numnum = int2str( frames );
-	// option_menu.addMenu( append("Frame rate ",numnum), normalFont, true,244,&frame_menu,select_smp);
-	//if ( window_mode == GFX_AUTODETECT )
-	//	option_menu->addMenu( strdup("Windowed"),Util::raptor_font,true,INIT_SCREEN,option_menu,select_smp);
-	//else    option_menu->addMenu( strdup("Fullscreen"),Util::raptor_font,true,INIT_SCREEN,option_menu,select_smp);
-	option_menu.addMenu( strdup("Windowed"), normalFont, true,INIT_SCREEN_WINDOW,&option_menu,select_smp);
-	option_menu.addMenu( strdup("Fullscreen"), normalFont, true,INIT_SCREEN_FULL,&option_menu,select_smp);
-	if ( dl )
-		option_menu.addMenu( strdup("Background on"), normalFont, true,INIT_BACK,&option_menu,select_smp);
-	else    option_menu.addMenu( strdup("Background off"), normalFont, true,INIT_BACK,&option_menu,select_smp);
-	option_menu.addMenu( strdup("Sound"), normalFont, true, 800, &sound_menu, select_smp );
-	option_menu.addMenu( strdup("Return to Menu"), normalFont, true,800,NULL,select_smp);
+	option_menu.addTitle( "Options", normalFont );
+	string numnum = int2str( frames );
+
+	RField * forwardKey = changeKeyMenu.addMenu( string("Forward: ") + Configuration::getForwardKeyName(), normalFont, true, CHANGE_KEY_FORWARD, &changeKeyMenu, select_smp );
+	RField * backwardKey = changeKeyMenu.addMenu( string("Backwards: ") + Configuration::getBackwardKeyName(), normalFont, true, CHANGE_KEY_BACKWARD, &changeKeyMenu, select_smp );
+	RField * leftKey = changeKeyMenu.addMenu( string("Left: ") + Configuration::getLeftKeyName(), normalFont, true, CHANGE_KEY_LEFT, &changeKeyMenu, select_smp );
+	RField * rightKey = changeKeyMenu.addMenu( string("Right: ") + Configuration::getRightKeyName(), normalFont, true, CHANGE_KEY_RIGHT, &changeKeyMenu, select_smp );
+	RField * shootKey = changeKeyMenu.addMenu( string("Shoot: ") + Configuration::getShootKeyName(), normalFont, true, CHANGE_KEY_SHOOT, &changeKeyMenu, select_smp );
+
+	changeKeyMenu.addMenu( "Return", normalFont, true, INIT_OPT, NULL, select_smp );
+
+	option_menu.addMenu( "Change Keys", normalFont, true, INIT_CHANGE_KEYS, &changeKeyMenu, select_smp );
+	
+	RField * fullscreenField;
+	if ( Configuration::getWindowMode() ){
+		fullscreenField = option_menu.addMenu( "Fullscreen on", normalFont, true,INIT_SCREEN,&option_menu,select_smp);
+	} else {
+		fullscreenField = option_menu.addMenu( "Fullscreen off",  normalFont, true,INIT_SCREEN,&option_menu,select_smp);
+	}
+
+	RField * backgroundField;
+	if ( Configuration::getBackground() ){
+		backgroundField = option_menu.addMenu( "Background off", normalFont, true, INIT_BACK, &option_menu, select_smp );
+	} else {
+		backgroundField = option_menu.addMenu( "Background on", normalFont, true, INIT_BACK, &option_menu, select_smp);
+	}
+	option_menu.addMenu( "Sound", normalFont, true, 800, &sound_menu, select_smp );
+	option_menu.addMenu( "Return to Menu", normalFont, true,800,NULL,select_smp);
 
 	/*
 	frame_menu.addTitle( append("Frame Rate ",numnum), normalFont );
-	//frame_menu->addTitle( strdup("Frame Rate is Unstable"),Util::raptor_font );
-	frame_menu.addMenu( strdup("Increase Rate"), normalFont, true,INC_RATE,&frame_menu,select_smp);
-	frame_menu.addMenu( strdup("Decrease Rate"), normalFont, true,DEC_RATE,&frame_menu,select_smp);
-	frame_menu.addMenu( strdup("Return to options"), normalFont, true,800,NULL,select_smp);
+	//frame_menu->addTitle( "Frame Rate is Unstable",Util::raptor_font );
+	frame_menu.addMenu( "Increase Rate", normalFont, true,INC_RATE,&frame_menu,select_smp);
+	frame_menu.addMenu( "Decrease Rate", normalFont, true,DEC_RATE,&frame_menu,select_smp);
+	frame_menu.addMenu( "Return to options", normalFont, true,800,NULL,select_smp);
 	*/
 
 	// char * sound_num = int2str( (int)(sound_vol * 100 ) );
@@ -347,27 +380,30 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 	/* make music_volume be the Music::volume */
 	sprintf( musicNum, "Music volume %d", (int)(Music::getVolume() * 100) );
 
-	sound_menu.addTitle( strdup(soundNum), &menuFont );
-	sound_menu.addMenu( strdup("Increase sound volume"), &menuFont, true, SOUND_INC, &sound_menu, select_smp );
-	sound_menu.addMenu( strdup("Decrease sound volume"), &menuFont, true, SOUND_DEC, &sound_menu, select_smp );
-	sound_menu.addTitle( strdup(musicNum), &menuFont );
-	sound_menu.addMenu( strdup("Increase music volume"), &menuFont, true, MUSIC_INC, &sound_menu, select_smp );
-	sound_menu.addMenu( strdup("Decrease music volume"), &menuFont, true, MUSIC_DEC, &sound_menu, select_smp );
-	sound_menu.addMenu( strdup("Return to options"), &menuFont, true,800,NULL,select_smp);
+	RField * soundTitle = sound_menu.addTitle( soundNum, &menuFont );
+	sound_menu.addMenu( "Increase sound volume", &menuFont, true, SOUND_INC, &sound_menu, select_smp );
+	sound_menu.addMenu( "Decrease sound volume", &menuFont, true, SOUND_DEC, &sound_menu, select_smp );
+	RField * musicTitle = sound_menu.addTitle( musicNum, &menuFont );
+	sound_menu.addMenu( "Increase music volume", &menuFont, true, MUSIC_INC, &sound_menu, select_smp );
+	sound_menu.addMenu( "Decrease music volume", &menuFont, true, MUSIC_DEC, &sound_menu, select_smp );
+	sound_menu.addMenu( "Return to options", &menuFont, true,800,NULL,select_smp);
 
-	difficulty_menu.addTitle( strdup("Difficulty"), &menuFont );
-	difficulty_menu.addMenu( strdup("Very Easy"), &menuFont, true, DIFFICULT_MENU+1, NULL, select_smp );
-	difficulty_menu.addMenu( strdup("Easy"), &menuFont, true, DIFFICULT_MENU+2, NULL, select_smp );
-	difficulty_menu.addMenu( strdup("Medium"), &menuFont, true, DIFFICULT_MENU+3, NULL, select_smp );
-	difficulty_menu.addMenu( strdup("Hard"), &menuFont, true, DIFFICULT_MENU+4, NULL, select_smp );
-	difficulty_menu.addMenu( strdup("Impossible"), &menuFont, true, DIFFICULT_MENU+5, NULL, select_smp );
+	difficulty_menu.addTitle( "Difficulty", &menuFont );
+	difficulty_menu.addMenu( "Very Easy", &menuFont, true, DIFFICULT_MENU+1, NULL, select_smp );
+	difficulty_menu.addMenu( "Easy", &menuFont, true, DIFFICULT_MENU+2, NULL, select_smp );
+	difficulty_menu.addMenu( "Medium", &menuFont, true, DIFFICULT_MENU+3, NULL, select_smp );
+	difficulty_menu.addMenu( "Hard", &menuFont, true, DIFFICULT_MENU+4, NULL, select_smp );
+	difficulty_menu.addMenu( "Impossible", &menuFont, true, DIFFICULT_MENU+5, NULL, select_smp );
 
 	RMenu * current = &intro_menu;
 	RMenu * temp = current;
 	current->init();
 
-	int g = -1;
-	while ( g != INIT_QUIT && g != INIT_CONTINUE && g != INIT_PLAY ) {
+	int option = -1;
+	while ( option != INIT_QUIT &&
+		option != INIT_CONTINUE &&
+		option != INIT_PLAY ) {
+
 		Util::YIELD();
 		// al_poll_duh( dumb_player );
 		/*
@@ -375,15 +411,15 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 		*/
 
 		temp = current;
-		g = current->procMenu( &current );
-		if ( !temp->Selected() ) g = -1;
+		option = current->procMenu( &current );
+		if ( !temp->Selected() ) option = -1;
 
 		bool changed_frames = false;
 		bool changed_sound = false;
 		bool changed_music = false;
 
-		if ( g > INIT_LOAD && g <= INIT_LOAD+6 ){
-			int load = g - INIT_LOAD;
+		if ( option > INIT_LOAD && option <= INIT_LOAD+6 ){
+			int load = option - INIT_LOAD;
 
 			// printf("Loading %d\n", load );
 			*player = loadPlayer( load );
@@ -394,10 +430,10 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 				snprintf( tmp, 64, "Error loading slot %d", load );
 				popUp( tmp );
 
-			} else g = INIT_CONTINUE;
+			} else option = INIT_CONTINUE;
 		}
 
-		switch ( g ) {
+		switch ( option ) {
 			case INC_RATE   : {
 				frames++;
 				changed_frames = true;
@@ -423,65 +459,112 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 				break;
 			}
 			case MUSIC_INC  : {
-				/*
-				music_vol += 0.02;
-				if ( music_vol > 1.0 ) music_vol = 1.0;
-				*/
 				Music::louden();
-				// dumb_player->louden();
 				changed_music = true;
 				break;
 			}
 			case MUSIC_DEC  : {
-				/*
-				music_vol -= 0.02;
-				if ( music_vol < 0 ) music_vol = 0;
-				*/
-				// dumb_player->soften();
 				Music::soften();
 				changed_music = true;
-
 				break;
 			}
 			case INIT_CREDITS       : {
 				do_credits();
 				break;
-			}
-						  /*
-			case INIT_SCREEN        : {
-			if ( window_mode == GFX_AUTODETECT_FULLSCREEN )
-			window_mode = GFX_AUTODETECT_WINDOWED;
-			else    window_mode = GFX_AUTODETECT_FULLSCREEN;
-			if ( window_mode == GFX_AUTODETECT_WINDOWED )
-			option_menu->replace( 3, strdup("Windowed"), Util::raptor_font,true, INIT_SCREEN, option_menu, select_smp  );
-			else    option_menu->replace( 3, strdup("Fullscreen"), Util::raptor_font,true, INIT_SCREEN, option_menu, select_smp );
-			printf("Setting gfx mode to %d - Status ",window_mode);
-			int cap = set_gfx_mode( window_mode, GRAPHICS_X, GRAPHICS_Y, 0, 0 );
-			printf("%d\n",cap );
-			if ( cap == -1 ) {
-			printf("Allegro error: %s\n", allegro_error );
-			set_gfx_mode(GFX_AUTODETECT,GRAPHICS_X,GRAPHICS_Y,0,0);
-			option_menu->replace(3,strdup("Error with gfx set"), Util::raptor_font,false, INIT_SCREEN, option_menu, select_smp );
 			}
 
-			break;
-			}
-			*/
-			case INIT_SCREEN_FULL   : {
-				Bitmap::setGfxModeFullscreen( GRAPHICS_X, GRAPHICS_Y );
-				break;
-			}
-			case INIT_SCREEN_WINDOW : {
-				Bitmap::setGfxModeWindowed( GRAPHICS_X, GRAPHICS_Y );
-				break;
-			}
-			case INIT_BACK          : {
-				if ( dl ) dl = false;else dl=true;
-				if ( dl ) option_menu.replace( 5, strdup("Background ON"), &menuFont, true, INIT_BACK, &option_menu, select_smp ); else
-					option_menu.replace( 5, strdup("Background off"), &menuFont, true, INIT_BACK, &option_menu, select_smp );
+			case CHANGE_KEY_FORWARD : {
+				int key = userSelectKey();
+				Configuration::setForwardKey( key );
+				stringstream stream;
+				stream << "Forward: " << Configuration::getForwardKeyName();
+				string str( stream.str() );
+				forwardKey->set( &str );
 				break;
 			}
 
+			case CHANGE_KEY_LEFT : {
+				int key = userSelectKey();
+				Configuration::setLeftKey( key );
+				stringstream stream;
+				stream << "Left: " << Configuration::getLeftKeyName();
+				string str( stream.str() );
+				leftKey->set( &str );
+				break;
+			}
+
+			case CHANGE_KEY_RIGHT : {
+				int key = userSelectKey();
+				Configuration::setRightKey( key );
+				stringstream stream;
+				stream << "Right: " << Configuration::getRightKeyName();
+				string str( stream.str() );
+				rightKey->set( &str );
+
+				break;
+			}
+
+			case CHANGE_KEY_BACKWARD : {
+				int key = userSelectKey();
+				Configuration::setBackwardKey( key );
+				stringstream stream;
+				stream << "Backwards: " << Configuration::getBackwardKeyName();
+				string str( stream.str() );
+				backwardKey->set( &str );
+				break;
+			}
+
+			case CHANGE_KEY_SHOOT : {
+				int key = userSelectKey();
+				Configuration::setShootKey( key );
+				stringstream stream;
+				stream << "Shoot: " << Configuration::getShootKeyName();
+				string str( stream.str() );
+				shootKey->set( &str );
+				break;
+			}
+			case INIT_SCREEN : {
+				Configuration::setWindowMode( ! Configuration::getWindowMode() );
+				if ( Configuration::getWindowMode() ) {
+					Bitmap::setGfxModeWindowed( GRAPHICS_X, GRAPHICS_Y );
+					string str( "Fullscreen off" );
+					fullscreenField->set( &str );
+				} else {
+					Bitmap::setGfxModeFullscreen( GRAPHICS_X, GRAPHICS_Y );
+					string str( "Fullscreen on" );
+					fullscreenField->set( &str );
+				}
+  				break;
+  			}
+			case INIT_BACK : {
+				Configuration::setBackground( ! Configuration::getBackground() );
+				if ( Configuration::getBackground() ){
+					// option_menu.replace( 5, "Background ON", &menuFont, true, INIT_BACK, &option_menu, select_smp );
+					string str( "Background Off" );
+					backgroundField->set( &str );
+				} else {
+					// option_menu.replace( 5, "Background off", &menuFont, true, INIT_BACK, &option_menu, select_smp );
+					string str( "Background On" );
+					backgroundField->set( &str );
+				}
+				break;
+			}
+
+		}
+
+		/* wait for enter/space to be released
+		 * so the user doesnt get into a loop of selecting
+		 * enter or space for the key and then modifying
+		 * that key again
+		 */
+		if ( option == CHANGE_KEY_SHOOT ||
+                     option == CHANGE_KEY_FORWARD ||
+                     option == CHANGE_KEY_BACKWARD ||
+                     option == CHANGE_KEY_LEFT ||
+                     option == CHANGE_KEY_RIGHT ){
+			while ( Keyboard::getAnyKey( Keyboard::SPACE, Keyboard::ENTER ) ){
+				Util::YIELD();
+			}
 		}
 
 		/*
@@ -495,23 +578,22 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 		*/
 
 		if ( changed_sound ) {
-			// free( sound_num );
-			// sound_num = int2str( (int)(sound_vol * 100 ) );
-			sprintf( soundNum, "Sound volume %d", (int)(Util::sound_vol * 100) );
-			sound_menu.replaceTitle( 1, strdup(soundNum), &menuFont );
+			stringstream stream;
+			stream << "Sound volume " << (int)(Util::sound_vol * 100);
+			string str( stream.str() );
+			soundTitle->set( &str );
 		}
 
 		if ( changed_music ) {
-			// free( music_num );
-			// music_num = int2str( (int)(music_vol * 100 ) );
-			sprintf( musicNum, "Music volume %d", (int)(Music::getVolume() * 100) );
-			sound_menu.replaceTitle( 4, strdup(musicNum), &menuFont );
-			// al_duh_set_volume( dumb_player, music_vol );
+			stringstream stream;
+			stream << "Music volume " << (int)(Music::getVolume() * 100);
+			string str( stream.str() );
+			musicTitle->set( &str );
 		}
 
 	}
 
-	if ( g == INIT_PLAY ) {
+	if ( option == INIT_PLAY ) {
 
 		if ( *player != NULL )
 			delete *player;
@@ -559,21 +641,16 @@ int intro_screen( int & frames, int window_mode, bool & dl, SpaceObject ** playe
 	delete difficulty_menu;
 	delete sound_menu;
 	*/
-	free( numnum );
 	// free( sound_num );
 	// free( music_num );
 
 	// destroy_bitmap( intr );
+	
+	Configuration::saveConfiguration();
 
-	return g;
-
-	#undef INC_RATE
-	#undef DEC_RATE
-
+	return option;
 }
 
-
-
 void usage(){
 
 	printf("OPTIONS\n");
@@ -708,6 +785,7 @@ void playLevel( PlayerObject * const player ){
 	Drawer draw;
 	Logic logic;
 	LevelCreator level( file_level, player ); 
+	draw.setDrawLand( Configuration::getBackground() );
 				
 	/* stop loading screen */
 	endLoadingScreen();
@@ -828,43 +906,20 @@ static vector< string > getSongs(){
 	return Util::getFiles( "music/", "*" );
 }
 
-/*
-static string getSong(){
-	struct al_ffblk info;
-	vector< string > files;
-
-	string dataPath = "music/";
-
-	if ( al_findfirst( (dataPath + "*").c_str(), &info, 0 ) != 0 ){
-		return "";
-	}
-	files.push_back( string( info.name ) );
-	while ( al_findnext( &info ) == 0 ){
-		files.push_back( string( info.name ) );
-	}
-	al_findclose( &info );
-
-	return dataPath + files[ Util::rnd( files.size() ) ];
-}
-*/
-
-//******************************MAIN**************************
 int rafkill( int argc, char ** argv ) {
 
-	int window = 0;
-	bool dl = true;
 	int gameSpeed = 40;
 
-	printf("raptor -h for help screen\n");
+	printf("rafkill -h for help screen\n");
 	for ( int q = 1; q < argc; q++ ) {
 		if ( strcmp( argv[q], "-h" ) == 0 || strcmp( argv[q], "-help" ) == 0 || strcmp( argv[q], "--help" ) == 0 ) {
 			usage();
 			return 0;
 		}
 		if ( strcmp( argv[q], "-w" ) == 0 ){
-			window = 1;
+			Configuration::setWindowMode( true );
 		} else if ( strcmp( argv[q], "-l" ) == 0 ){
-			dl = false;
+			Configuration::setBackground( false );
 		} else if ( strlen( argv[q] ) > 2 ){
 			if ( argv[q][1] == 'g' ){
 				gameSpeed = atoi( &argv[q][2] );
@@ -877,8 +932,8 @@ int rafkill( int argc, char ** argv ) {
 	}
 
 	cout << "Running game at " << gameSpeed << endl;
-	cout << "Using mode " << window << endl;
-	init( window, gameSpeed );
+	cout << "Using window mode " << Configuration::getWindowMode() << endl;
+	init( Configuration::getWindowMode(), gameSpeed );
 	cout << "OS " << Util::getOS() << endl;
 
 	Util::loadGlobals();
@@ -914,7 +969,7 @@ int rafkill( int argc, char ** argv ) {
 	bool quit;
 	// int real_level = 1;
 	int geti;
-	while ( (geti = intro_screen( gameSpeed, window, dl, &player, Util::global_snd ) ) != INIT_QUIT ) {
+	while ( (geti = intro_screen( gameSpeed, &player, Util::global_snd ) ) != INIT_QUIT ) {
 		quit = geti == INIT_QUIT;
 		while ( ! quit ) {
 
@@ -947,6 +1002,8 @@ int rafkill( int argc, char ** argv ) {
 		delete player;
 	}
 
+	// Configuration::saveConfiguration();
+
 	cout << "Unloading data" << endl;
 
 	Util::unloadGlobals();
