@@ -1,13 +1,13 @@
 #ifndef _raptor_font_h
 #define _raptor_font_h
 
-#include "allegro.h"
+#include "bitmap.h"
 
 class RGlyph{
 public:
 	RGlyph( int w, int h, unsigned char * dat, char mc );
 
-	void Draw( BITMAP * work, int x, int y, int c );
+	void Draw( const Bitmap & work, int x, int y, int c );
 	bool rightLetter( char x );
 	int height();
 	int width();
@@ -26,9 +26,8 @@ class RFont{
 public:
 	RFont( char * fname );
 
-	void rtext( BITMAP * work, int x, int y, int c, char * wr );
+	void rtext( const Bitmap & work, int x, int y, int c, const char * wr );
 	int height();
-	int width( char * w );
 
 	~RFont();
 
