@@ -4,7 +4,7 @@
 #include "trigtable.h"
 #include "sound.h"
 #include "defs.h"
-#include "rafkill.h"
+#include "raptor.h"
 #include "explode.h"
 
 WeaponNode::WeaponNode(int qx, int qy, double kx, double ky, HullObject * hnew, int alignment):
@@ -16,20 +16,25 @@ bool WeaponNode::Damage( double much ) {
 	return true;
 }
 
+bool WeaponNode::hullCollide( ECollide * col, int x, int y ){
+	return false;
+}
+	
+bool WeaponNode::CanbeHit( const SpaceObject * ht ) const{
+	return false;
+}
 
-void WeaponNode::Died( SpaceObject * check, ExplosionClass ** explr, int ME, DATAFILE * sd ) {
-	play_sound( sd, sustain, 50 );
+void WeaponNode::Died( SpaceObject * check, ExplosionClass ** explr, int ME ){
+	Util::playSound( SND_SUSTAIN, 50 );
 	Explode( explr, ME );
 }
 
-
 void WeaponNode::Explode( ExplosionClass ** explr, int ME ) {
-	//double a = (double)( rnd( 45 ) + 15 ) / -10.0;
-	//addExplode( explr, ME, new ExplosionClass(actualx,actualy,0,a,rnd(6) + 3 ) );
-	addExplode( explr, ME, new ExplosionClass(actualx,actualy,this->DX()/2,this->DY()/2,rnd(6) + 3 ) );
+	//double a = (double)( Util::rnd( 45 ) + 15 ) / -10.0;
+	//addExplode( explr, ME, new ExplosionClass(actualx,actualy,0,a,Util::rnd(6) + 3 ) );
+	addExplode( explr, ME, new ExplosionClass(getX(),getY(),this->getDX()/2,this->getDY()/2,Util::rnd(6) + 3 ) );
 
 }
 
-
 WeaponNode::~WeaponNode() {
 }
